@@ -8,9 +8,6 @@
  *            Hans-Joachim Picht <hans@linux.vnet.ibm.com>
  */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
 #include <fenv.h>
 #include <time.h>
 #include <fcntl.h>
