@@ -830,7 +830,7 @@ static void dasdview_print_vtoc_info(dasdview_info_t *info)
 	if ((info->f1c < 1) && (info->f8c < 1))	{
 	        printf("There are no partitions defined.\n");
 	} else {
-	        printf("Other S/390 and zSeries operating systems would see " \
+	        printf("Other mainframe operating systems would see " \
 		       "the following data sets:\n");
 		printf(" +----------------------------------------------+" \
 		       "--------------+--------------+\n");
