@@ -7,9 +7,6 @@
  * Copyright IBM Corp. 2001,2012
  */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
 #include <getopt.h>
 #include <stdio.h>
 
