@@ -23,6 +23,7 @@ static u32		l_cpu_type_selected_mask;
 static int		l_cpu_type_cnt;
 static int		l_sys_item_cnt;
 static int		l_cpu_item_cnt;
+static int		l_has_core_data;
 static struct sd_sys	*l_root_sys;
 
 /*
@@ -145,15 +146,15 @@ void sd_update(void)
 /*
  * Register a data gatherer
  */
-void sd_dg_register(struct sd_dg *dg)
+void sd_dg_register(struct sd_dg *dg, int has_core_data)
 {
 	struct timespec ts = {0, SD_DG_INIT_INTERVAL_MS * 1000000};
 	struct sd_sys_item *sys_item;
 	struct sd_cpu_item *cpu_item;
 	unsigned int i;
 
+	l_has_core_data = has_core_data;
 	sd.dg = dg;
-
 	for (i = 0; dg->cpu_type_vec[i]; i++)
 		dg->cpu_type_vec[i]->idx = (1UL << i);
 	l_cpu_type_cnt = i;
@@ -169,6 +170,14 @@ void sd_dg_register(struct sd_dg *dg)
 	l_cpu_types_init();
 }
 
+/*
+ * Does backend has core data?
+ */
+int sd_dg_has_core_data(void)
+{
+	return l_has_core_data;
+}
+
 /*
  * Get CPU from sys by ID
  */
@@ -249,6 +258,7 @@ struct sd_sys *sd_sys_new(struct sd_sys *parent, const char *id)
 		parent->child_cnt++;
 		util_list_add_tail(&parent->child_list, sys_new);
 	}
+	sys_new->threads_per_core = 1;
 	return sys_new;
 }
 
@@ -314,7 +324,6 @@ static void l_cpu_update_end(struct sd_sys *sys)
 	/* Has system not lost any CPU? */
 	if (sys->cpu_cnt_active == sys->cpu_cnt)
 		return;
-
 	util_list_iterate_safe(&sys->cpu_list, cpu, tmp) {
 		if (!cpu->i.active) {
 			/* CPU has not been updated, remove it */
@@ -323,6 +332,7 @@ static void l_cpu_update_end(struct sd_sys *sys)
 			continue;
 		}
 	}
+	sys->cpu_cnt = sys->cpu_cnt_active;
 }
 
 /*
