@@ -9,10 +9,6 @@
 #ifndef UTIL_LIST_H
 #define UTIL_LIST_H
 
-#ifndef UTIL_H
-#warning "Please include util.h and not util_list.h directly!"
-#endif
-
 #include <stddef.h>
 
 struct util_list {
