@@ -24,8 +24,10 @@
 #define TOOLS_LIBDIR	STRINGIFY (S390_TOOLS_LIBDIR)
 #define TOOLS_SYSCONFDIR STRINGIFY (S390_TOOLS_SYSCONFDIR)
 
+#define __noreturn __attribute__((noreturn))
 #define __packed __attribute__((packed))
 #define __aligned(x) __attribute__((aligned(x)))
+#define __may_alias __attribute__((may_alias))
 
 typedef unsigned long long	u64;
 typedef signed long long	s64;
