@@ -297,6 +297,7 @@ LOGFILES="\
   /var/log/lin_tape.trace\
   /var/log/lin_tape.errorlog\
   /var/log/messages*\
+  /var/log/syslog*\
   /var/log/sa\
   /var/log/yum.log\
   /var/log/openvswitch/ovs-vswitchd.log\
@@ -432,6 +433,7 @@ CMDS="uname -a\
   :cat /root/.bash_history\
   :env\
   :journalctl --all --no-pager --since=$(date -d '5 day ago' +%Y-%m-%d) --until=now --lines=50000 > ${OUTPUT_FILE_JOURNALCTL}\
+  :openssl engine\
   :systemd-delta\
   :systemctl --all --no-pager show\
   :systemctl --all --no-pager list-units\
@@ -444,6 +446,8 @@ VM_CMDS="q userid\
   :q users\
   :q privclass\
   :q cplevel\
+  :q cpservice\
+  :q ssi\
   :q cpus\
   :q srm\
   :q vtod\
@@ -620,20 +624,29 @@ collect_sysfs() {
 	    fi
 	fi
 
-	call_run_command "find /sys -print0 | sort -z | xargs -0 -n 10 ls -ld" "${OUTPUT_FILE_SYSFS}"
+	# Collect sysfs files using multiple threads (-J 1) while excluding
+	# files known to block on read (-x). Stop reading a file that takes
+	# more than 5 seconds (-T 5) such as an active ftrace buffer.
+	dump2tar /sys -z -o "${WORKPATH}/sysfs.tgz" -x '*/tracing/trace_pipe*' \
+		 -x '*/tracing/per_cpu/*' --ignore-failed-read -J 1 -T 5
 
-	find /sys -noleaf -type d 2>/dev/null | while IFS= read -r dir_name; do
-	    mkdir -p "${WORKPATH}${dir_name}"
-	done
+	if [ $? -ne 0 ] ; then
+	    echo "${SCRIPTNAME}: Warning: dump2tar failed or is unavailable - falling back to slow path"
+	    call_run_command "find /sys -print0 | sort -z | xargs -0 -n 10 ls -ld" "${OUTPUT_FILE_SYSFS}"
 
-	find /sys -noleaf -type f -perm /444\
-		  -a -not -name "*trace_pipe*"\
-		  2>/dev/null | while IFS= read -r file_name; do
-	    echo " ${file_name}"
-	    if ! dd if="${file_name}" status=noxfer iflag=nonblock of="${WORKPATH}${file_name}" >/dev/null 2>&1; then
-		echo "${SCRIPTNAME}: Warning: failed to copy \"${file_name}\""
-	    fi
-	done
+	    find /sys -noleaf -type d 2>/dev/null | while IFS= read -r dir_name; do
+	        mkdir -p "${WORKPATH}${dir_name}"
+	    done
+
+	    find /sys -noleaf -type f -perm /444\
+		      -a -not -name "*trace_pipe*"\
+		      2>/dev/null | while IFS= read -r file_name; do
+		echo " ${file_name}"
+		if ! dd if="${file_name}" status=noxfer iflag=nonblock of="${WORKPATH}${file_name}" >/dev/null 2>&1; then
+		    echo "${SCRIPTNAME}: Warning: failed to copy \"${file_name}\""
+		fi
+	    done
+	fi
 
 	if test ${debugfs_mounted} -eq 1; then
 	    umount "${MOUNT_POINT_DEBUGFS}"
