@@ -9,6 +9,7 @@
 
 #include "disk.h"
 #include "tunedasd.h"
+#include "dasd_sys.h"
 
 #include <sys/types.h>
 #include <sys/ioctl.h>
@@ -682,3 +683,37 @@ disk_reset_prof (char* device)
 	return 0;
 }
 
+int disk_reset_chpid(char *device, char *chpid)
+{
+	int rc;
+
+	if (chpid)
+		printf("Resetting chpid %s for device <%s>...\n", chpid,
+		       device);
+	else
+		printf("Resetting all chpids for device <%s>...\n", device);
+
+	rc = dasd_reset_chpid(device, chpid);
+	switch (rc) {
+	case 0:
+		printf("Done.\n");
+		return 0;
+	case ENODEV:
+		error_print("%s: %s", device, strerror(errno));
+		break;
+	case EINVAL:
+		error_print("%s: Could not reset chpid %s: Invalid CHPID",
+			     device, chpid);
+		break;
+	case ENOENT:
+		error_print("%s: Could not reset chpid %s: CHPID not defined for device",
+			     device, chpid);
+		break;
+	default:
+		error_print("%s: Could not reset chpid %s",
+			     device, chpid);
+		break;
+	}
+
+	return -1;
+}
