@@ -34,28 +34,30 @@ static const char* usage_text[] = {
 	"(e.g. '/dev/dasda') or a list of devices separated by a space "
 	"character.",
 	"",
-	"-h, --help               Print this help, then exit",
-	"-v, --version            Print version information, then exit",
-	"-g, --get_cache          Get current storage server caching behaviour",
-	"-c, --cache <behavior>   Define caching behavior on storage server",
-	"                         (normal/bypass/inhibit/sequential/prestage/"
-	                          "record)",
-	"-n, --no_cyl <n>         Number of cylinders to be cached ",
-	"                         (only valid together with --cache)",
-	"-S, --reserve            Reserve device",
-	"-L, --release            Release device",
-	"-O, --slock              Unconditional reserve device",
-	"                         Note: Use with care, this breaks an existing "
-	                          "lock",
-	"-Q, --query_reserve      Print reserve status of device ",
-	"-P, --profile            Print profile info of device",
-	"-I, --prof_item          Print single profile item",
-	"                         (reqs/sects/sizes/total/totsect/start/irq/",
-	"                         irqsect/end/queue)",
-	"-R, --reset_prof         Reset profile info of device"
+	"-h, --help                Print this help, then exit",
+	"-v, --version             Print version information, then exit",
+	"-g, --get_cache           Get current storage server caching behaviour",
+	"-c, --cache <behavior>    Define caching behavior on storage server",
+	"                          (normal/bypass/inhibit/sequential/prestage/"
+	                           "record)",
+	"-n, --no_cyl <n>          Number of cylinders to be cached ",
+	"                          (only valid together with --cache)",
+	"-S, --reserve             Reserve device",
+	"-L, --release             Release device",
+	"-O, --slock               Unconditional reserve device",
+	"                          Note: Use with care, this breaks an existing "
+	                           "lock",
+	"-Q, --query_reserve       Print reserve status of device ",
+	"-P, --profile             Print profile info of device",
+	"-I, --prof_item           Print single profile item",
+	"                          (reqs/sects/sizes/total/totsect/start/irq/",
+	"                          irqsect/end/queue)",
+	"-R, --reset_prof          Reset profile info of device",
+	"-p, --path_reset <chpid>  Reset channel path <chpid> of a device",
+	"    --path_reset_all      Reset all channel paths of a device"
 };
 
-#define CMD_KEYWORD_NUM		12
+#define CMD_KEYWORD_NUM		14
 #define DEVICES_NUM		256
 
 enum cmd_keyword_id {
@@ -71,6 +73,8 @@ enum cmd_keyword_id {
 	cmd_keyword_prof_item      =  9,
 	cmd_keyword_reset_prof     = 10,
 	cmd_keyword_query_reserve  = 11,
+	cmd_keyword_path           = 12,
+	cmd_keyword_path_all       = 13,
 };
 
 
@@ -79,18 +83,20 @@ static const struct {
 	char* keyword;
 	enum cmd_keyword_id id;
 } keyword_list[] = {
-	{ "help",          cmd_keyword_help },
-	{ "version",       cmd_keyword_version },
-	{ "get_cache",     cmd_keyword_get_cache },
-	{ "cache",         cmd_keyword_cache },
-	{ "no_cyl",        cmd_keyword_no_cyl },
-	{ "reserve",       cmd_keyword_reserve },
-	{ "release",       cmd_keyword_release },
-	{ "slock",         cmd_keyword_slock },
-	{ "profile",       cmd_keyword_profile },
-	{ "prof_item",     cmd_keyword_prof_item },
-	{ "reset_prof",    cmd_keyword_reset_prof },
-	{ "query_reserve", cmd_keyword_query_reserve }
+	{ "help",           cmd_keyword_help },
+	{ "version",        cmd_keyword_version },
+	{ "get_cache",      cmd_keyword_get_cache },
+	{ "cache",          cmd_keyword_cache },
+	{ "no_cyl",         cmd_keyword_no_cyl },
+	{ "reserve",        cmd_keyword_reserve },
+	{ "release",        cmd_keyword_release },
+	{ "slock",          cmd_keyword_slock },
+	{ "profile",        cmd_keyword_profile },
+	{ "prof_item",      cmd_keyword_prof_item },
+	{ "reset_prof",     cmd_keyword_reset_prof },
+	{ "query_reserve",  cmd_keyword_query_reserve },
+	{ "path_reset",     cmd_keyword_path },
+	{ "path_reset_all", cmd_keyword_path_all }
 };	
 
 
@@ -103,22 +109,24 @@ enum cmd_key_state {
 
 /* Determines which combination of keywords are valid */
 enum cmd_key_state cmd_key_table[CMD_KEYWORD_NUM][CMD_KEYWORD_NUM] = {
-	/*		     help vers get_ cach no_c rese rele sloc prof prof rese quer
-	 *		          ion  cach e    yl   rve  ase  k    ile  _ite t_pr y_re
+	/*		      help vers get_ cach no_c rese rele sloc prof prof rese quer path path
+	 *		           ion  cach e    yl   rve  ase  k    ile  _ite t_pr y_re      _all
 	 *		               	e                                  m    of  serv
 	 */
-	/* help  	 */ { req, opt, opt, opt, opt, opt, opt, opt, opt, opt, opt, inv },
-	/* version	 */ { inv, req, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv },
-	/* get_cache	 */ { opt, opt, req, inv, inv, inv, inv, inv, inv, inv, inv, inv },
-	/* cache 	 */ { opt, opt, inv, req, opt, inv, inv, inv, inv, inv, inv, inv },
-	/* no_cyl	 */ { opt, opt, inv, req, req, inv, inv, inv, inv, inv, inv, inv },
-	/* reserve	 */ { opt, opt, inv, inv, inv, req, inv, inv, inv, inv, inv, inv },
-	/* release	 */ { opt, opt, inv, inv, inv, inv, req, inv, inv, inv, inv, inv },
-	/* slock 	 */ { opt, opt, inv, inv, inv, inv, inv, req, inv, inv, inv, inv },
-	/* profile	 */ { opt, opt, inv, inv, inv, inv, inv, inv, req, opt, inv, inv },
-	/* prof_item	 */ { opt, opt, inv, inv, inv, inv, inv, inv, req, req, inv, inv },
-	/* reset_prof	 */ { opt, opt, inv, inv, inv, inv, inv, inv, inv, inv, req, inv },
-	/* query_reserve */ { inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, req },
+	/* help  	 */ { req, opt, opt, opt, opt, opt, opt, opt, opt, opt, opt, inv, inv, inv },
+	/* version	 */ { inv, req, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv },
+	/* get_cache	 */ { opt, opt, req, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv },
+	/* cache 	 */ { opt, opt, inv, req, opt, inv, inv, inv, inv, inv, inv, inv, inv, inv },
+	/* no_cyl	 */ { opt, opt, inv, req, req, inv, inv, inv, inv, inv, inv, inv, inv, inv },
+	/* reserve	 */ { opt, opt, inv, inv, inv, req, inv, inv, inv, inv, inv, inv, inv, inv },
+	/* release	 */ { opt, opt, inv, inv, inv, inv, req, inv, inv, inv, inv, inv, inv, inv },
+	/* slock 	 */ { opt, opt, inv, inv, inv, inv, inv, req, inv, inv, inv, inv, inv, inv },
+	/* profile	 */ { opt, opt, inv, inv, inv, inv, inv, inv, req, opt, inv, inv, inv, inv },
+	/* prof_item	 */ { opt, opt, inv, inv, inv, inv, inv, inv, req, req, inv, inv, inv, inv },
+	/* reset_prof	 */ { opt, opt, inv, inv, inv, inv, inv, inv, inv, inv, req, inv, inv, inv },
+	/* query_reserve */ { inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, req, inv, inv },
+	/* path          */ { inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, req, inv },
+	/* path_all      */ { inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, inv, req },
 };
 
 struct parameter {
@@ -146,11 +154,13 @@ static struct option options[] = {
 	{ "prof_item",		required_argument,      NULL, 'I'},
 	{ "reset_prof",		no_argument,	        NULL, 'R'},
 	{ "query_reserve",	no_argument,	        NULL, 'Q'},
+	{ "path_reset",		required_argument,      NULL, 'p'},
+	{ "path_reset_all",	no_argument,            NULL, 'A'},
 	{ NULL,			0,			NULL, 0 }
 };
 
 /* Command line option abbreviations */
-static const char option_string[] = "hvgc:n:SLOPI:RQ";
+static const char option_string[] = "hvgc:n:SLOPI:RQp:";
 
 
 /* Error message string */
@@ -348,6 +358,14 @@ get_command_line (int argc, char* argv[], struct command_line* line)
 						   optarg);
 			}
 			break;
+		case 'p':
+			rc = store_option(&cmdline, cmd_keyword_path,
+					  optarg);
+			break;
+		case 'A':
+			rc = store_option(&cmdline, cmd_keyword_path_all,
+					  optarg);
+			break;
 		case 'S':
 			rc = store_option (&cmdline, cmd_keyword_reserve,
 					   optarg);
@@ -400,7 +418,6 @@ get_command_line (int argc, char* argv[], struct command_line* line)
 	return 0;
 }
 
-
 /*
  * Execute the command.
  */
@@ -444,6 +461,13 @@ do_command (char* device, struct command_line cmdline)
 	case cmd_keyword_query_reserve:
 		rc = disk_query_reserve_status(device);
 		break;
+	case cmd_keyword_path:
+		rc = disk_reset_chpid(device,
+				      cmdline.parm[cmd_keyword_path].data);
+		break;
+	case cmd_keyword_path_all:
+		rc = disk_reset_chpid(device, NULL);
+		break;
 	default:
 		error_print ("Unknown command '%s' specified",
 			     get_keyword_name (i));
