@@ -32,7 +32,7 @@
 #include <linux/types.h>
 #include "zt_common.h"
 #include "vmur.h"
-#include "dump.h"
+#include "vmdump.h"
 
 /* Program name */
 static char *prog_name;
@@ -1796,10 +1796,11 @@ static void ur_receive(struct vmur *info)
 		} else {
 			close(fhi);
 			if (info->stdout_specified)
-				rc = vm_convert(info->devnode, NULL, prog_name);
+				rc = vmdump_convert(info->devnode, NULL,
+						    prog_name);
 			else
-				rc = vm_convert(info->devnode, info->file_name,
-						prog_name);
+				rc = vmdump_convert(info->devnode,
+						    info->file_name, prog_name);
 			if (rc)
 				goto fail;
 			else
