@@ -4,8 +4,6 @@
  * Author(s): Peter Oberparleiter <oberpar@linux.vnet.ibm.com>
  */
 
-#define _GNU_SOURCE		/* For string.h:basename(). */
-
 #include "ccwgroup.h"
 
 #include <stdio.h>
@@ -797,6 +795,32 @@ static void ccwgroup_st_add_persistent_ids(struct subtype *st,
 	udev_ccwgroup_add_device_ids(st->name, ids);
 }
 
+/* Check if CCW device ID @b is part of CCW group device ID @a. */
+static bool id_contains(struct ccwgroup_devid *a, struct ccw_devid *b)
+{
+	unsigned int i;
+
+	for (i = 0; i < a->num; i++) {
+		if (ccw_cmp_devids(&a->devid[i], b) == 0)
+			return true;
+	}
+
+	return false;
+}
+
+/* Check if there are common CCW device IDs in @a and @b. */
+static bool id_overlap(struct ccwgroup_devid *a, struct ccwgroup_devid *b)
+{
+	unsigned int i;
+
+	for (i = 0; i < a->num; i++) {
+		if (id_contains(b, &a->devid[i]))
+			return true;
+	}
+
+	return false;
+}
+
 /* Remove all CCW device IDs which are part of CCW group device %dev from
  * %list. */
 static void ccwgroup_st_rem_combined(struct subtype *st, struct device *dev,
@@ -805,8 +829,7 @@ static void ccwgroup_st_rem_combined(struct subtype *st, struct device *dev,
 {
 	struct selected_dev_node *p, *n;
 	struct ccw_devid devid;
-	struct ccwgroup_devid *gdevid;
-	unsigned int i;
+	struct ccwgroup_devid groupid, *gdevid;
 
 	gdevid = dev->devid;
 	util_list_iterate_safe(list, p, n) {
@@ -818,15 +841,18 @@ static void ccwgroup_st_rem_combined(struct subtype *st, struct device *dev,
 		}
 		if (p->st != st)
 			continue;
-		if (!ccw_parse_devid_simple(&devid, p->id))
-			continue;
-		for (i = 0; i < gdevid->num; i++) {
-			if (ccw_cmp_devids(&devid, &gdevid->devid[i]) == 0) {
-				util_list_remove(list, p);
-				selected_dev_free(p);
-				break;
-			}
+		if (ccw_parse_devid_simple(&devid, p->id)) {
+			if (id_contains(gdevid, &devid))
+				goto remove;
+		} else if (ccwgroup_parse_devid_simple(&groupid, p->id)) {
+			if (id_overlap(gdevid, &groupid))
+				goto remove;
 		}
+		continue;
+
+remove:
+		util_list_remove(list, p);
+		selected_dev_free(p);
 	}
 }
 
