@@ -298,7 +298,7 @@ static exit_code_t match_state_and_add(struct select_opts *select,
 	if (!select_match_state(dev, select))
 		return EXIT_OK;
 
-	sel = selected_dev_list_add(selected, dt, st, id, param, 0);
+	sel = selected_dev_list_add(selected, dt, st, dev->id, param, 0);
 
 	if (match_ptr && !*match_ptr)
 		*match_ptr = sel;
