@@ -38,6 +38,7 @@ struct vol_parm_table {
 	u64		timestamp;
 	u16		vol_cnt;
 	struct vol_parm	vol_parm[MAX_VOLUMES];
+	u8		ssid[MAX_VOLUMES];
 } __attribute__ ((packed));
 
 /*
@@ -231,11 +232,12 @@ static void df_s390mv_mem_read(struct dfi_mem_chunk *mem_chunk, u64 off,
 /*
  * Initialize DASD volume
  */
-static void vol_init(struct vol *vol, struct vol_parm *vol_parm, u64 *mem_off)
+static void vol_init(struct vol *vol, struct vol_parm *vol_parm, int ssid,
+		     u64 *mem_off)
 {
 	u64 blk_cnt = vol_parm->end_blk - vol_parm->start_blk + 1;
 
-	sprintf(vol->bus_id, "0.0.%04x", vol_parm->devno);
+	sprintf(vol->bus_id, "0.%x.%04x", ssid, vol_parm->devno);
 	vol->blk_size = vol_parm->blk_size << 8;
 	vol->part_off = vol_parm->start_blk * vol->blk_size;
 	vol->part_size = blk_cnt * vol->blk_size;
@@ -458,7 +460,8 @@ static void volumes_init(void)
 
 	for (i = 0; i < l.table.vol_cnt; i++) {
 		l.vol_vec[i].nr = i;
-		vol_init(&l.vol_vec[i], &l.table.vol_parm[i], &mem_off);
+		vol_init(&l.vol_vec[i], &l.table.vol_parm[i], l.table.ssid[i],
+			 &mem_off);
 	}
 	if (mem_off != l.hdr.mem_size)
 		l.dump_incomplete = 1;
