@@ -244,7 +244,7 @@ static inline uint32_t csum_partial(const void *buf, int len, uint32_t sum)
 }
 
 #define __ctl_store(array, low, high) ({		    \
-	typedef struct { char _[sizeof(array)]; } addrtype; \
+	typedef struct { char _[sizeof(array)]; } __may_alias addrtype;\
 	asm volatile(					    \
 		"	stctg	%1,%2,%0\n"		    \
 		: "=Q" (*(addrtype *)(&array))		    \
@@ -252,7 +252,7 @@ static inline uint32_t csum_partial(const void *buf, int len, uint32_t sum)
 })
 
 #define __ctl_load(array, low, high) ({			    \
-	typedef struct { char _[sizeof(array)]; } addrtype; \
+	typedef struct { char _[sizeof(array)]; } __may_alias addrtype; \
 	asm volatile(					    \
 		"	lctlg	%1,%2,%0\n"			\
 		: : "Q" (*(addrtype *)(&array)),		\
