@@ -726,9 +726,9 @@ build_program_table(int fd, struct job_data* job, disk_blockptr_t* pointer,
 	case job_dump_partition:
 		/* Only useful for a partition dump that uses a dump kernel*/
 		if (job->command_line)
-			printf("Adding fs-dump section\n");
+			printf("Adding dump section\n");
 		else
-			printf("Adding fs-dump section '%s' (default)\n",
+			printf("Adding dump section '%s' (default)\n",
 			       job->name);
 		rc = add_dump_program(fd, &job->data.dump, &table[0],
 					 verbose || job->command_line,
